# abrio-cli
  SDK used By Developers to create custom logic for their apps.


## CLI configurations for local usage 
  to test the cli tool :

  + move to cli directory and create a virtual env
  ```
  cd cli
  virtualenv venv
  . venv/bin/activate
  ```

  + install AbrIO CLI locally using
  ```
  pip install --editable .
  ```

  Abrio CLI is now installed. 
  
## Abrio CLI on PyPi 
  Abrio cli is now on PyPiTest repository. install it using
   
  ```
  pip install AbrIO
  # if not found : 
  pip install --extra-index-url https://testpypi.python.org/pypi AbrIO
  ```
